@@ -1,6 +1,6 @@
 /*************************************************************************************************
  * Test cases of Cabin
- *                                                      Copyright (C) 2000-2004 Mikio Hirabayashi
+ *                                                      Copyright (C) 2000-2005 Mikio Hirabayashi
  * This file is part of QDBM, Quick Database Manager.
  * QDBM is free software; you can redistribute it and/or modify it under the terms of the GNU
  * Lesser General Public License as published by the Free Software Foundation; either version
@@ -20,6 +20,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <stdarg.h>
+#include <limits.h>
 #include <time.h>
 
 #undef TRUE
@@ -54,7 +55,7 @@ int strpcmp(const void *ap, const void *bp);
 int myrand(void);
 int dosort(int rnum, int disp);
 int dolist(int rnum, int disp);
-int domap(int rnum, int disp);
+int domap(int rnum, int bnum, int disp);
 int dowicked(int rnum);
 int domisc(void);
 
@@ -90,7 +91,7 @@ void usage(void){
   fprintf(stderr, "usage:\n");
   fprintf(stderr, "  %s sort [-d] rnum\n", progname);
   fprintf(stderr, "  %s list [-d] rnum\n", progname);
-  fprintf(stderr, "  %s map [-d] rnum\n", progname);
+  fprintf(stderr, "  %s map [-d] rnum [bnum]\n", progname);
   fprintf(stderr, "  %s wicked rnum\n", progname);
   fprintf(stderr, "  %s misc\n", progname);
   fprintf(stderr, "\n");
@@ -156,10 +157,12 @@ int runlist(int argc, char **argv){
 
 /* parse arguments of map command */
 int runmap(int argc, char **argv){
-  int i, rnum, disp, rv;
-  char *rstr;
+  int i, rnum, bnum, disp, rv;
+  char *rstr, *bstr;
   rstr = NULL;
+  bstr = NULL;
   rnum = 0;
+  bnum = -1;
   disp = FALSE;
   for(i = 2; i < argc; i++){
     if(argv[i][0] == '-'){
@@ -170,6 +173,8 @@ int runmap(int argc, char **argv){
       }
     } else if(!rstr){
       rstr = argv[i];
+    } else if(!bstr){
+      bstr = argv[i];
     } else {
       usage();
     }
@@ -177,7 +182,8 @@ int runmap(int argc, char **argv){
   if(!rstr) usage();
   rnum = atoi(rstr);
   if(rnum < 1) usage();
-  rv = domap(rnum, disp);
+  if(bstr) bnum = atoi(bstr);
+  rv = domap(rnum, bnum, disp);
   return rv;
 }
 
@@ -335,13 +341,13 @@ int dolist(int rnum, int disp){
 
 
 /* perform list command */
-int domap(int rnum, int disp){
+int domap(int rnum, int bnum, int disp){
   CBMAP *map;
   int i, err, len;
   char buf[RECBUFSIZ];
   const char *val;
-  if(!disp) prinfflush("<Map Writing Test>\n  rnum=%d  disp=%d\n\n", rnum, disp);
-  map = cbmapopen();
+  if(!disp) prinfflush("<Map Writing Test>\n  rnum=%d  bnum=%d  disp=%d\n\n", rnum, bnum, disp);
+  map = bnum > 0 ? cbmapopenex(bnum) : cbmapopen();
   err = FALSE;
   for(i = 1; i <= rnum; i++){
     len = sprintf(buf, "%08d", i);
@@ -383,7 +389,7 @@ int dowicked(int rnum){
   prinfflush("<Wicked Writing Test>\n  rnum=%d\n\n", rnum);
   list = cblistopen();
   for(i = 1; i <= rnum; i++){
-    len = sprintf(buf, "%08d", myrand() % rnum + 1);
+    len = sprintf(buf, "%d", myrand() % rnum + 1);
     switch(myrand() % 16){
     case 0:
       free(cblistpop(list, NULL));
@@ -405,6 +411,10 @@ int dowicked(int rnum){
       free(cblistremove(list, myrand() % (cblistnum(list) + 1), NULL));
       putchar('R');
       break;
+    case 5:
+      cblistover(list, myrand() % (cblistnum(list) + 1), buf, len);
+      putchar('V');
+      break;
     default:
       cblistpush(list, buf, len);
       putchar('P');
@@ -415,21 +425,25 @@ int dowicked(int rnum){
   cblistclose(list);
   map = cbmapopen();
   for(i = 1; i <= rnum; i++){
-    len = sprintf(buf, "%08d", myrand() % rnum + 1);
+    len = sprintf(buf, "%d", myrand() % rnum + 1);
     switch(myrand() % 16){
     case 0:
       cbmapput(map, buf, len, buf, len, FALSE);
       putchar('I');
       break;
     case 1:
+      cbmapputcat(map, buf, len, buf, len);
+      putchar('C');
+      break;
+    case 2:
       cbmapget(map, buf, len, NULL);
       putchar('V');
       break;
-    case 2:
+    case 3:
       cbmapout(map, buf, len);
       putchar('D');
       break;
-    case 3:
+    case 4:
       cbmapmove(map, buf, len, myrand() % 2);
       putchar('M');
       break;
@@ -450,9 +464,10 @@ int dowicked(int rnum){
 int domisc(void){
   CBLIST *olist, *nlist, *elems, *glist;
   CBMAP *omap, *nmap, *pairs, *gmap;
-  int i, j, ssiz, osiz;
+  int i, j, ssiz, osiz, jl;
   char kbuf[RECBUFSIZ], vbuf[RECBUFSIZ], *sbuf, spbuf[1024], *tmp, *orig, renc[64];
   const char *op, *np;
+  time_t t;
   prinfflush("<Miscellaneous Test>\n\n");
   prinfflush("Checking serialization of list ... ");
   olist = cblistopen();
@@ -618,7 +633,7 @@ int domisc(void){
   }
   free(orig);
   free(tmp);
-  strcpy(spbuf, "&lt;Nuts&amp;Milk&gt; is &quot;very&quot; fun!");
+  strcpy(spbuf, "&lt;Nuts&amp;Milk&gt; is &quot;very&quot; surfin&apos;!");
   tmp = cbxmlunescape(spbuf);
   orig = cbxmlescape(tmp);
   if(strcmp(orig, spbuf)){
@@ -630,6 +645,35 @@ int domisc(void){
   free(orig);
   free(tmp);
   prinfflush("ok\n");
+  prinfflush("Checking date utilities ... ");
+  for(i = 0; i < 200; i++){
+    jl = (myrand() % 23) * 1800;
+    if(myrand() % 2 == 0) jl *= -1;
+    t = myrand() % (INT_MAX - 3600 * 24) + 3600 * 24;
+    tmp = cbdatestrwww(t, jl);
+    t = cbstrmktime(tmp);
+    orig = cbdatestrwww(t, jl);
+    if(strcmp(orig, tmp)){
+      free(orig);
+      free(tmp);
+      fprintf(stderr, "%s: W3CDTF formatter is invalid\n", progname);
+      return 1;
+    }
+    free(orig);
+    free(tmp);
+    tmp = cbdatestrhttp(t, jl);
+    t = cbstrmktime(tmp);
+    orig = cbdatestrhttp(t, jl);
+    if(strcmp(orig, tmp)){
+      free(orig);
+      free(tmp);
+      fprintf(stderr, "%s: RFC 1123 formatter is invalid\n", progname);
+      return 1;
+    }
+    free(orig);
+    free(tmp);
+  }
+  prinfflush("ok\n");
   prinfflush("Checking the global garbage collector ... ");
   for(i = 0; i < 512; i++){
     glist = cblistopen();
