@@ -1,6 +1,6 @@
 /*************************************************************************************************
  * Utility for debugging Curia and its applications
- *                                                      Copyright (C) 2000-2004 Mikio Hirabayashi
+ *                                                      Copyright (C) 2000-2005 Mikio Hirabayashi
  * This file is part of QDBM, Quick Database Manager.
  * QDBM is free software; you can redistribute it and/or modify it under the terms of the GNU
  * Lesser General Public License as published by the Free Software Foundation; either version
@@ -54,10 +54,12 @@ int runoptimize(int argc, char **argv);
 int runinform(int argc, char **argv);
 int runremove(int argc, char **argv);
 int runrepair(int argc, char **argv);
+int runexportdb(int argc, char **argv);
+int runimportdb(int argc, char **argv);
 void pdperror(const char *name);
 void printobj(const char *obj, int size);
 void printobjhex(const char *obj, int size);
-int docreate(const char *name, int bnum, int dnum);
+int docreate(const char *name, int bnum, int dnum, int sparse);
 int doput(const char *name, const char *kbuf, int ksiz,
           const char *vbuf, int vsiz, int dmode, int lob, int align);
 int doout(const char *name, const char *kbuf, int ksiz, int lob);
@@ -68,6 +70,8 @@ int dooptimize(const char *name, int bnum, int align);
 int doinform(const char *name);
 int doremove(const char *name);
 int dorepair(const char *name);
+int doexportdb(const char *name, const char *dir);
+int doimportdb(const char *name, const char *dir);
 
 
 /* main routine */
@@ -97,9 +101,13 @@ int main(int argc, char **argv){
     rv = runremove(argc, argv);
   } else if(!strcmp(argv[1], "repair")){
     rv = runrepair(argc, argv);
+  } else if(!strcmp(argv[1], "exportdb")){
+    rv = runexportdb(argc, argv);
+  } else if(!strcmp(argv[1], "importdb")){
+    rv = runimportdb(argc, argv);
   } else if(!strcmp(argv[1], "version") || !strcmp(argv[1], "--version")){
     printf("Powered by QDBM version %s on %s\n", dpversion, dpsysname);
-    printf("Copyright (c) 2000-2004 Mikio Hirabayashi\n");
+    printf("Copyright (c) 2000-2005 Mikio Hirabayashi\n");
     rv = 0;
   } else {
     usage();
@@ -113,7 +121,7 @@ void usage(void){
   fprintf(stderr, "%s: administration utility for Curia\n", progname);
   fprintf(stderr, "\n");
   fprintf(stderr, "usage:\n");
-  fprintf(stderr, "  %s create [-bnum num] [-dnum num] name\n", progname);
+  fprintf(stderr, "  %s create [-s] [-bnum num] [-dnum num] name\n", progname);
   fprintf(stderr, "  %s put [-kx|-ki] [-vx|-vi|-vf] [-keep|-cat] [-lob] [-na] "
           "name key val\n", progname);
   fprintf(stderr, "  %s out [-kx|-ki] [-lob] name key\n", progname);
@@ -124,6 +132,8 @@ void usage(void){
   fprintf(stderr, "  %s inform name\n", progname);
   fprintf(stderr, "  %s remove name\n", progname);
   fprintf(stderr, "  %s repair name\n", progname);
+  fprintf(stderr, "  %s exportdb name dir\n", progname);
+  fprintf(stderr, "  %s importdb name dir\n", progname);
   fprintf(stderr, "  %s version\n", progname);
   fprintf(stderr, "\n");
   exit(1);
@@ -167,13 +177,16 @@ char *dectoiobj(const char *str, int *sp){
 /* parse arguments of create command */
 int runcreate(int argc, char **argv){
   char *name;
-  int i, bnum, dnum, rv;
+  int i, sb, bnum, dnum, rv;
   name = NULL;
+  sb = FALSE;
   bnum = -1;
   dnum = -1;
   for(i = 2; i < argc; i++){
     if(!name && argv[i][0] == '-'){
-      if(!strcmp(argv[i], "-bnum")){
+      if(!strcmp(argv[i], "-s")){
+        sb = TRUE;
+      } else if(!strcmp(argv[i], "-bnum")){
         if(++i >= argc) usage();
         bnum = atoi(argv[i]);
       } else if(!strcmp(argv[i], "-dnum")){
@@ -189,7 +202,7 @@ int runcreate(int argc, char **argv){
     }
   }
   if(!name) usage();
-  rv = docreate(name, bnum, dnum);
+  rv = docreate(name, bnum, dnum, sb);
   return rv;
 }
 
@@ -502,6 +515,52 @@ int runrepair(int argc, char **argv){
 }
 
 
+/* parse arguments of exportdb command */
+int runexportdb(int argc, char **argv){
+  char *name, *dir;
+  int i, rv;
+  name = NULL;
+  dir = NULL;
+  for(i = 2; i < argc; i++){
+    if(!name && argv[i][0] == '-'){
+      usage();
+    } else if(!name){
+      name = argv[i];
+    } else if(!dir){
+      dir = argv[i];
+    } else {
+      usage();
+    }
+  }
+  if(!name || !dir) usage();
+  rv = doexportdb(name, dir);
+  return rv;
+}
+
+
+/* parse arguments of importdb command */
+int runimportdb(int argc, char **argv){
+  char *name, *dir;
+  int i, rv;
+  name = NULL;
+  dir = NULL;
+  for(i = 2; i < argc; i++){
+    if(!name && argv[i][0] == '-'){
+      usage();
+    } else if(!name){
+      name = argv[i];
+    } else if(!dir){
+      dir = argv[i];
+    } else {
+      usage();
+    }
+  }
+  if(!name || !dir) usage();
+  rv = doimportdb(name, dir);
+  return rv;
+}
+
+
 /* print an error message */
 void pdperror(const char *name){
   fprintf(stderr, "%s: %s: %s\n", progname, name, dperrmsg(dpecode));
@@ -527,9 +586,11 @@ void printobjhex(const char *obj, int size){
 
 
 /* perform create command */
-int docreate(const char *name, int bnum, int dnum){
+int docreate(const char *name, int bnum, int dnum, int sparse){
   CURIA *curia;
-  if(!(curia = cropen(name, CR_OWRITER | CR_OCREAT | CR_OTRUNC, bnum, dnum))){
+  int omode;
+  omode = CR_OWRITER | CR_OCREAT | CR_OTRUNC | (sparse ? CR_OSPARSE : 0);
+  if(!(curia = cropen(name, omode, bnum, dnum))){
     pdperror(name);
     return 1;
   }
@@ -716,6 +777,7 @@ int doinform(const char *name){
   printf("used buckets: %d\n", crbusenum(curia));
   printf("records: %d\n", crrnum(curia));
   printf("inode number: %d\n", crinode(curia));
+  printf("modified time: %d\n", crmtime(curia));
   printf("LOB records: %d\n", crrnumlob(curia));
   if(!crclose(curia)){
     pdperror(name);
@@ -745,4 +807,45 @@ int dorepair(const char *name){
 }
 
 
+/* perform exportdb command */
+int doexportdb(const char *name, const char *dir){
+  CURIA *curia;
+  if(!(curia = cropen(name, CR_OREADER, -1, -1))){
+    pdperror(name);
+    return 1;
+  }
+  if(!crexportdb(curia, dir)){
+    pdperror(name);
+    crclose(curia);
+    return 1;
+  }
+  if(!crclose(curia)){
+    pdperror(name);
+    return 1;
+  }
+  return 0;
+}
+
+
+/* perform importdb command */
+int doimportdb(const char *name, const char *dir){
+  CURIA *curia;
+  if(!(curia = cropen(name, CR_OWRITER | CR_OCREAT | CR_OTRUNC, -1, -1))){
+    pdperror(name);
+    return 1;
+  }
+  if(!crimportdb(curia, dir)){
+    pdperror(name);
+    crclose(curia);
+    return 1;
+  }
+  if(!crclose(curia)){
+    pdperror(name);
+    return 1;
+  }
+  return 0;
+}
+
+
+
 /* END OF FILE */
