@@ -1,6 +1,6 @@
 /*************************************************************************************************
  * Test cases of Curia
- *                                                      Copyright (C) 2000-2004 Mikio Hirabayashi
+ *                                                      Copyright (C) 2000-2005 Mikio Hirabayashi
  * This file is part of QDBM, Quick Database Manager.
  * QDBM is free software; you can redistribute it and/or modify it under the terms of the GNU
  * Lesser General Public License as published by the Free Software Foundation; either version
@@ -53,7 +53,7 @@ int runwicked(int argc, char **argv);
 int printfflush(const char *format, ...);
 void pdperror(const char *name);
 int myrand(void);
-int dowrite(const char *name, int rnum, int bnum, int dnum, int lob);
+int dowrite(const char *name, int rnum, int bnum, int dnum, int sparse, int lob);
 int doread(const char *name, int wb, int lob);
 int dorcat(const char *name, int rnum, int bnum, int dnum, int pnum, int align);
 int docombo(const char *name);
@@ -91,7 +91,7 @@ void usage(void){
   fprintf(stderr, "%s: test cases for Curia\n", progname);
   fprintf(stderr, "\n");
   fprintf(stderr, "usage:\n");
-  fprintf(stderr, "  %s write [-lob] name rnum bnum dnum\n", progname);
+  fprintf(stderr, "  %s write [-s] [-lob] name rnum bnum dnum\n", progname);
   fprintf(stderr, "  %s read [-wb] [-lob] name\n", progname);
   fprintf(stderr, "  %s rcat name rnum bnum dnum pnum align\n", progname);
   fprintf(stderr, "  %s combo name\n", progname);
@@ -104,7 +104,7 @@ void usage(void){
 /* parse arguments of write command */
 int runwrite(int argc, char **argv){
   char *name, *rstr, *bstr, *dstr;
-  int i, rnum, bnum, dnum, lob, rv;
+  int i, rnum, bnum, dnum, sb, lob, rv;
   name = NULL;
   rstr = NULL;
   bstr = NULL;
@@ -112,10 +112,13 @@ int runwrite(int argc, char **argv){
   rnum = 0;
   bnum = 0;
   dnum = 0;
+  sb = FALSE;
   lob = FALSE;
   for(i = 2; i < argc; i++){
     if(!name && argv[i][0] == '-'){
-      if(!strcmp(argv[i], "-lob")){
+      if(!strcmp(argv[i], "-s")){
+        sb = TRUE;
+      } else if(!strcmp(argv[i], "-lob")){
         lob = TRUE;
       } else {
         usage();
@@ -137,7 +140,7 @@ int runwrite(int argc, char **argv){
   bnum = atoi(bstr);
   dnum = atoi(dstr);
   if(rnum < 1 || bnum < 1 || dnum < 1) usage();
-  rv = dowrite(name, rnum, bnum, dnum, lob);
+  rv = dowrite(name, rnum, bnum, dnum, sb, lob);
   return rv;
 }
 
@@ -288,14 +291,15 @@ int myrand(void){
 
 
 /* perform write command */
-int dowrite(const char *name, int rnum, int bnum, int dnum, int lob){
+int dowrite(const char *name, int rnum, int bnum, int dnum, int sparse, int lob){
   CURIA *curia;
-  int i, err, len;
+  int i, omode, err, len;
   char buf[RECBUFSIZ];
   printfflush("<Writing Test>\n  name=%s  rnum=%d  bnum=%d  dnum=%d  lob=%d\n\n",
               name, rnum, bnum, dnum, lob);
   /* open a database */
-  if(!(curia = cropen(name, CR_OWRITER | CR_OCREAT | CR_OTRUNC, bnum, dnum))){
+  omode = CR_OWRITER | CR_OCREAT | CR_OTRUNC | (sparse ? CR_OSPARSE : 0);
+  if(!(curia = cropen(name, omode, bnum, dnum))){
     pdperror(name);
     return 1;
   }
