@@ -1,6 +1,6 @@
 /*************************************************************************************************
  * Utility for debugging Depot and its applications
- *                                                      Copyright (C) 2000-2004 Mikio Hirabayashi
+ *                                                      Copyright (C) 2000-2005 Mikio Hirabayashi
  * This file is part of QDBM, Quick Database Manager.
  * QDBM is free software; you can redistribute it and/or modify it under the terms of the GNU
  * Lesser General Public License as published by the Free Software Foundation; either version
@@ -53,10 +53,12 @@ int runoptimize(int argc, char **argv);
 int runinform(int argc, char **argv);
 int runremove(int argc, char **argv);
 int runrepair(int argc, char **argv);
+int runexportdb(int argc, char **argv);
+int runimportdb(int argc, char **argv);
 void pdperror(const char *name);
 void printobj(const char *obj, int size);
 void printobjhex(const char *obj, int size);
-int docreate(const char *name, int bnum);
+int docreate(const char *name, int bnum, int sparse);
 int doput(const char *name, const char *kbuf, int ksiz, const char *vbuf, int vsiz,
           int dmode, int align);
 int doout(const char *name, const char *kbuf, int ksiz);
@@ -66,6 +68,8 @@ int dooptimize(const char *name, int bnum, int align);
 int doinform(const char *name);
 int doremove(const char *name);
 int dorepair(const char *name);
+int doexportdb(const char *name, const char *file);
+int doimportdb(const char *name, const char *file);
 
 
 /* main routine */
@@ -95,9 +99,13 @@ int main(int argc, char **argv){
     rv = runremove(argc, argv);
   } else if(!strcmp(argv[1], "repair")){
     rv = runrepair(argc, argv);
+  } else if(!strcmp(argv[1], "exportdb")){
+    rv = runexportdb(argc, argv);
+  } else if(!strcmp(argv[1], "importdb")){
+    rv = runimportdb(argc, argv);
   } else if(!strcmp(argv[1], "version") || !strcmp(argv[1], "--version")){
     printf("Powered by QDBM version %s on %s\n", dpversion, dpsysname);
-    printf("Copyright (c) 2000-2004 Mikio Hirabayashi\n");
+    printf("Copyright (c) 2000-2005 Mikio Hirabayashi\n");
     rv = 0;
   } else {
     usage();
@@ -111,7 +119,7 @@ void usage(void){
   fprintf(stderr, "%s: administration utility for Depot\n", progname);
   fprintf(stderr, "\n");
   fprintf(stderr, "usage:\n");
-  fprintf(stderr, "  %s create [-bnum num] name\n", progname);
+  fprintf(stderr, "  %s create [-s] [-bnum num] name\n", progname);
   fprintf(stderr, "  %s put [-kx|-ki] [-vx|-vi|-vf] [-keep|-cat] [-na] name key val\n",
           progname);
   fprintf(stderr, "  %s out [-kx|-ki] name key\n", progname);
@@ -122,6 +130,8 @@ void usage(void){
   fprintf(stderr, "  %s inform name\n", progname);
   fprintf(stderr, "  %s remove name\n", progname);
   fprintf(stderr, "  %s repair name\n", progname);
+  fprintf(stderr, "  %s exportdb name file\n", progname);
+  fprintf(stderr, "  %s importdb name file\n", progname);
   fprintf(stderr, "  %s version\n", progname);
   fprintf(stderr, "\n");
   exit(1);
@@ -165,12 +175,15 @@ char *dectoiobj(const char *str, int *sp){
 /* parse arguments of create command */
 int runcreate(int argc, char **argv){
   char *name;
-  int i, bnum, rv;
+  int i, sb, bnum, rv;
   name = NULL;
+  sb = FALSE;
   bnum = -1;
   for(i = 2; i < argc; i++){
     if(!name && argv[i][0] == '-'){
-      if(!strcmp(argv[i], "-bnum")){
+      if(!strcmp(argv[i], "-s")){
+        sb = TRUE;
+      } else if(!strcmp(argv[i], "-bnum")){
         if(++i >= argc) usage();
         bnum = atoi(argv[i]);
       } else {
@@ -183,7 +196,7 @@ int runcreate(int argc, char **argv){
     }
   }
   if(!name) usage();
-  rv = docreate(name, bnum);
+  rv = docreate(name, bnum, sb);
   return rv;
 }
 
@@ -487,6 +500,52 @@ int runrepair(int argc, char **argv){
 }
 
 
+/* parse arguments of exportdb command */
+int runexportdb(int argc, char **argv){
+  char *name, *file;
+  int i, rv;
+  name = NULL;
+  file = NULL;
+  for(i = 2; i < argc; i++){
+    if(!name && argv[i][0] == '-'){
+      usage();
+    } else if(!name){
+      name = argv[i];
+    } else if(!file){
+      file = argv[i];
+    } else {
+      usage();
+    }
+  }
+  if(!name || !file) usage();
+  rv = doexportdb(name, file);
+  return rv;
+}
+
+
+/* parse arguments of importdb command */
+int runimportdb(int argc, char **argv){
+  char *name, *file;
+  int i, rv;
+  name = NULL;
+  file = NULL;
+  for(i = 2; i < argc; i++){
+    if(!name && argv[i][0] == '-'){
+      usage();
+    } else if(!name){
+      name = argv[i];
+    } else if(!file){
+      file = argv[i];
+    } else {
+      usage();
+    }
+  }
+  if(!name || !file) usage();
+  rv = doimportdb(name, file);
+  return rv;
+}
+
+
 /* print an error message */
 void pdperror(const char *name){
   fprintf(stderr, "%s: %s: %s\n", progname, name, dperrmsg(dpecode));
@@ -512,9 +571,11 @@ void printobjhex(const char *obj, int size){
 
 
 /* perform create command */
-int docreate(const char *name, int bnum){
+int docreate(const char *name, int bnum, int sparse){
   DEPOT *depot;
-  if(!(depot = dpopen(name, DP_OWRITER | DP_OCREAT | DP_OTRUNC, bnum))){
+  int omode;
+  omode = DP_OWRITER | DP_OCREAT | DP_OTRUNC | (sparse ? DP_OSPARSE : 0);
+  if(!(depot = dpopen(name, omode, bnum))){
     pdperror(name);
     return 1;
   }
@@ -679,6 +740,7 @@ int doinform(const char *name){
   printf("used buckets: %d\n", dpbusenum(depot));
   printf("records: %d\n", dprnum(depot));
   printf("inode number: %d\n", dpinode(depot));
+  printf("modified time: %d\n", dpmtime(depot));
   if(!dpclose(depot)){
     pdperror(name);
     return 1;
@@ -707,5 +769,45 @@ int dorepair(const char *name){
 }
 
 
+/* perform exportdb command */
+int doexportdb(const char *name, const char *file){
+  DEPOT *depot;
+  if(!(depot = dpopen(name, DP_OREADER, -1))){
+    pdperror(name);
+    return 1;
+  }
+  if(!dpexportdb(depot, file)){
+    pdperror(name);
+    dpclose(depot);
+    return 1;
+  }
+  if(!dpclose(depot)){
+    pdperror(name);
+    return 1;
+  }
+  return 0;
+}
+
+
+/* perform importdb command */
+int doimportdb(const char *name, const char *file){
+  DEPOT *depot;
+  if(!(depot = dpopen(name, DP_OWRITER | DP_OCREAT | DP_OTRUNC, -1))){
+    pdperror(name);
+    return 1;
+  }
+  if(!dpimportdb(depot, file)){
+    pdperror(name);
+    dpclose(depot);
+    return 1;
+  }
+  if(!dpclose(depot)){
+    pdperror(name);
+    return 1;
+  }
+  return 0;
+}
+
+
 
 /* END OF FILE */
