@@ -1,6 +1,6 @@
 /*************************************************************************************************
  * Test cases of Depot
- *                                                      Copyright (C) 2000-2004 Mikio Hirabayashi
+ *                                                      Copyright (C) 2000-2005 Mikio Hirabayashi
  * This file is part of QDBM, Quick Database Manager.
  * QDBM is free software; you can redistribute it and/or modify it under the terms of the GNU
  * Lesser General Public License as published by the Free Software Foundation; either version
@@ -52,7 +52,7 @@ int runwicked(int argc, char **argv);
 int printfflush(const char *format, ...);
 void pdperror(const char *name);
 int myrand(void);
-int dowrite(const char *name, int rnum, int bnum);
+int dowrite(const char *name, int rnum, int bnum, int sparse);
 int doread(const char *name, int wb);
 int dorcat(const char *name, int rnum, int bnum, int pnum, int align);
 int docombo(const char *name);
@@ -90,7 +90,7 @@ void usage(void){
   fprintf(stderr, "%s: test cases for Depot\n", progname);
   fprintf(stderr, "\n");
   fprintf(stderr, "usage:\n");
-  fprintf(stderr, "  %s write name rnum bnum\n", progname);
+  fprintf(stderr, "  %s write [-s] name rnum bnum\n", progname);
   fprintf(stderr, "  %s read [-wb] name\n", progname);
   fprintf(stderr, "  %s rcat name rnum bnum pnum align\n", progname);
   fprintf(stderr, "  %s combo name\n", progname);
@@ -103,15 +103,20 @@ void usage(void){
 /* parse arguments of write command */
 int runwrite(int argc, char **argv){
   char *name, *rstr, *bstr;
-  int i, rnum, bnum, rv;
+  int i, rnum, bnum, sb, rv;
   name = NULL;
   rstr = NULL;
   bstr = NULL;
   rnum = 0;
   bnum = 0;
+  sb = FALSE;
   for(i = 2; i < argc; i++){
     if(!name && argv[i][0] == '-'){
-      usage();
+      if(!strcmp(argv[i], "-s")){
+        sb = TRUE;
+      } else {
+        usage();
+      }
     } else if(!name){
       name = argv[i];
     } else if(!rstr){
@@ -126,7 +131,7 @@ int runwrite(int argc, char **argv){
   rnum = atoi(rstr);
   bnum = atoi(bstr);
   if(rnum < 1 || bnum < 1) usage();
-  rv = dowrite(name, rnum, bnum);
+  rv = dowrite(name, rnum, bnum, sb);
   return rv;
 }
 
@@ -270,13 +275,14 @@ int myrand(void){
 
 
 /* perform write command */
-int dowrite(const char *name, int rnum, int bnum){
+int dowrite(const char *name, int rnum, int bnum, int sparse){
   DEPOT *depot;
-  int i, err, len;
+  int i, omode, err, len;
   char buf[RECBUFSIZ];
   printfflush("<Writing Test>\n  name=%s  rnum=%d  bnum=%d\n\n", name, rnum, bnum);
   /* open a database */
-  if(!(depot = dpopen(name, DP_OWRITER | DP_OCREAT | DP_OTRUNC, bnum))){
+  omode = DP_OWRITER | DP_OCREAT | DP_OTRUNC | (sparse ? DP_OSPARSE : 0);
+  if(!(depot = dpopen(name, omode, bnum))){
     pdperror(name);
     return 1;
   }
