@@ -1,6 +1,6 @@
 /*************************************************************************************************
  * Java API of Depot, the basic API of QDBM
- *                                                      Copyright (C) 2000-2004 Mikio Hirabayashi
+ *                                                      Copyright (C) 2000-2005 Mikio Hirabayashi
  * This file is part of QDBM, Quick Database Manager.
  * QDBM is free software; you can redistribute it and/or modify it under the terms of the GNU
  * Lesser General Public License as published by the Free Software Foundation; either version
@@ -81,6 +81,8 @@ public class Depot implements ADBM {
   public static final int OTRUNC = 1 << 3;
   /** open mode: open without locking */
   public static final int ONOLCK = 1 << 4;
+  /** open mode: create as a sparse file */
+  public static final int OSPARSE = 1 << 5;
   //----------------------------------------------------------------
   // write modes
   //----------------------------------------------------------------
@@ -145,7 +147,8 @@ public class Depot implements ADBM {
    * `Depot.OCREAT', which means it creates a new database if not exist, `Depot.OTRUNC',
    * which means it creates a new database regardless if one exists.  Both of `Depot.OREADER'
    * and `Depot.OWRITER' can be added to by bitwise or: `Depot.ONOLCK', which means it opens a
-   * database file without file locking.
+   * database file without file locking.  `Depot.OCREAT' can be added to by bitwise or:
+   * `Depot.OSPARSE', which means it creates a database file as a sparse file.
    * @param bnum the number of elements of the bucket array.  If it is not more than 0,
    * the default value is specified.  The size of a bucket array is determined on creating,
    * and can not be changed except for by optimization of the database.  Suggested size of a
