@@ -1,6 +1,6 @@
 /*************************************************************************************************
  * C++ API of Curia, the extended API of QDBM
- *                                                      Copyright (C) 2000-2004 Mikio Hirabayashi
+ *                                                      Copyright (C) 2000-2005 Mikio Hirabayashi
  * This file is part of QDBM, Quick Database Manager.
  * QDBM is free software; you can redistribute it and/or modify it under the terms of the GNU
  * Lesser General Public License as published by the Free Software Foundation; either version
@@ -70,25 +70,25 @@ public:
   /**
    * Equality operator.
    * @param ce a comparing instance.
-   * @return true if the both equal, else, false.
+   * @return true if both equal, else, false.
    */
   virtual bool operator ==(const Curia_error& ce) const throw();
   /**
    * Inequality operator.
    * @param ce a comparing instance.
-   * @return true if the both do not equal, else, false.
+   * @return true if both do not equal, else, false.
    */
   virtual bool operator !=(const Curia_error& ce) const throw();
   /**
    * Equality operator.
    * @param ecode a comparing error code.
-   * @return true if the both equal, else, false.
+   * @return true if both equal, else, false.
    */
   virtual bool operator ==(int ecode) const throw();
   /**
    * Inequality operator.
    * @param ecode a comparing error code.
-   * @return true if the both do not equal, else, false.
+   * @return true if both do not equal, else, false.
    */
   virtual bool operator !=(int ecode) const throw();
   /**
@@ -150,6 +150,7 @@ public:
   static const int OCREAT;            ///< open mode: writer creating
   static const int OTRUNC;            ///< open mode: writer truncating
   static const int ONOLCK;            ///< open mode: open without locking
+  static const int OSPARSE;           ///< open mode: create as sparse files
   static const int DOVER;             ///< write mode: overwrite the existing value
   static const int DKEEP;             ///< write mode: keep the existing value
   static const int DCAT;              ///< write mode: concatenate values
@@ -180,7 +181,8 @@ public:
    * `Curia::OCREAT', which means it creates a new database if not exist, `Curia::OTRUNC',
    * which means it creates a new database regardless if one exists.  Both of `Curia::OREADER'
    * and `Curia::OWRITER' can be added to by bitwise or: `Curia::ONOLCK', which means it opens a
-   * database directory without file locking.
+   * database directory without file locking.  `Curia::OCREAT' can be added to by bitwise or:
+   * `Curia::OSPARSE', which means it creates database files as sparse files.
    * @param bnum the number of elements of each bucket array.  If it is not more than 0,
    * the default value is specified.  The size of each bucket array is determined on creating,
    * and can not be changed except for by optimization of the database.  Suggested size of each
@@ -384,6 +386,12 @@ public:
    * @throw Curia_error if an error occurs.
    */
   virtual int inode() throw(Curia_error);
+  /**
+   * Get the last modified time of the database.
+   * @return the last modified time the database.
+   * @throw Curia_error if an error occurs.
+   */
+  virtual int mtime() throw(Curia_error);
   /**
    * Store a large object.
    * @param kbuf the pointer to the region of a key.
