@@ -1,6 +1,6 @@
 /*************************************************************************************************
  * C++ API of Depot, the basic API of QDBM
- *                                                      Copyright (C) 2000-2004 Mikio Hirabayashi
+ *                                                      Copyright (C) 2000-2005 Mikio Hirabayashi
  * This file is part of QDBM, Quick Database Manager.
  * QDBM is free software; you can redistribute it and/or modify it under the terms of the GNU
  * Lesser General Public License as published by the Free Software Foundation; either version
@@ -69,25 +69,25 @@ public:
   /**
    * Equality operator.
    * @param de a comparing instance.
-   * @return true if the both equal, else, false.
+   * @return true if both equal, else, false.
    */
   virtual bool operator ==(const Depot_error& de) const throw();
   /**
    * Inequality operator.
    * @param de a comparing instance.
-   * @return true if the both do not equal, else, false.
+   * @return true if both do not equal, else, false.
    */
   virtual bool operator !=(const Depot_error& de) const throw();
   /**
    * Equality operator.
    * @param ecode a comparing error code.
-   * @return true if the both equal, else, false.
+   * @return true if both equal, else, false.
    */
   virtual bool operator ==(int ecode) const throw();
   /**
    * Inequality operator.
    * @param ecode a comparing error code.
-   * @return true if the both do not equal, else, false.
+   * @return true if both do not equal, else, false.
    */
   virtual bool operator !=(int ecode) const throw();
   /**
@@ -149,6 +149,7 @@ public:
   static const int OCREAT;            ///< open mode: writer creating
   static const int OTRUNC;            ///< open mode: writer truncating
   static const int ONOLCK;            ///< open mode: open without locking
+  static const int OSPARSE;           ///< open mode: create as a sparse file
   static const int DOVER;             ///< write mode: overwrite the existing value
   static const int DKEEP;             ///< write mode: keep the existing value
   static const int DCAT;              ///< write mode: concatenate values
@@ -179,7 +180,8 @@ public:
    * `Depot::OCREAT', which means it creates a new database if not exist, `Depot::OTRUNC',
    * which means it creates a new database regardless if one exists.  Both of `Depot::OREADER'
    * and `Depot::OWRITER' can be added to by bitwise or: `Depot::ONOLCK', which means it opens a
-   * database file without file locking.
+   * database file without file locking.  `Depot::OCREAT' can be added to by bitwise or:
+   * `Depot::OSPARSE', which means it creates a database file as a sparse file.
    * @param bnum the number of elements of the bucket array.  If it is not more than 0,
    * the default value is specified.  The size of a bucket array is determined on creating,
    * and can not be changed except for by optimization of the database.  Suggested size of a
@@ -373,6 +375,12 @@ public:
    * @throw Depot_error if an error occurs.
    */
   virtual int inode() throw(Depot_error);
+  /**
+   * Get the last modified time of the database.
+   * @return the last modified time the database.
+   * @throw Depot_error if an error occurs.
+   */
+  virtual int mtime() throw(Depot_error);
   /**
    * Get the file descriptor of the database file.
    * @return the file descriptor of the database file.
