@@ -1,6 +1,6 @@
 /*************************************************************************************************
  * C++ API of Villa, the advanced API of QDBM
- *                                                      Copyright (C) 2000-2004 Mikio Hirabayashi
+ *                                                      Copyright (C) 2000-2005 Mikio Hirabayashi
  * This file is part of QDBM, Quick Database Manager.
  * QDBM is free software; you can redistribute it and/or modify it under the terms of the GNU
  * Lesser General Public License as published by the Free Software Foundation; either version
@@ -71,25 +71,25 @@ public:
   /**
    * Equality operator.
    * @param ve a comparing instance.
-   * @return true if the both equal, else, false.
+   * @return true if both equal, else, false.
    */
   virtual bool operator ==(const Villa_error& ve) const throw();
   /**
    * Inequality operator.
    * @param ve a comparing instance.
-   * @return true if the both do not equal, else, false.
+   * @return true if both do not equal, else, false.
    */
   virtual bool operator !=(const Villa_error& ve) const throw();
   /**
    * Equality operator.
    * @param ecode a comparing error code.
-   * @return true if the both equal, else, false.
+   * @return true if both equal, else, false.
    */
   virtual bool operator ==(int ecode) const throw();
   /**
    * Inequality operator.
    * @param ecode a comparing error code.
-   * @return true if the both do not equal, else, false.
+   * @return true if both do not equal, else, false.
    */
   virtual bool operator !=(int ecode) const throw();
   /**
@@ -444,6 +444,12 @@ public:
    * @throw Villa_error if an error occurs.
    */
   virtual int inode() throw(Villa_error);
+  /**
+   * Get the last modified time of the database.
+   * @return the last modified time the database.
+   * @throw Villa_error if an error occurs.
+   */
+  virtual int mtime() throw(Villa_error);
   /**
    * Begin the transaction.
    * @throw Villa_error if an error occurs.
