@@ -1,6 +1,6 @@
 /*************************************************************************************************
  * Test cases of Villa for C++
- *                                                      Copyright (C) 2000-2004 Mikio Hirabayashi
+ *                                                      Copyright (C) 2000-2005 Mikio Hirabayashi
  * This file is part of QDBM, Quick Database Manager.
  * QDBM is free software; you can redistribute it and/or modify it under the terms of the GNU
  * Lesser General Public License as published by the Free Software Foundation; either version
@@ -41,7 +41,7 @@ const int LCNUM = 32;
 const int NCNUM = 32;
 
 
-/* struct for argument of threads */
+/* struct for closure per thread */
 struct Mission {
   Villa* villa;
   int rnum;
@@ -548,6 +548,7 @@ int domisc(const char* name){
     cout << "  - writable ... " << villa->writable() << endl;
     cout << "  - fatalerror ... " << villa->fatalerror() << endl;
     cout << "  - inode ... " << villa->inode() << endl;
+    cout << "  - mtime ... " << villa->mtime() << endl;
     cout << "ok" << endl;
     // close the database
     cout << "Closing the database ... ";
