@@ -1,6 +1,6 @@
 /*************************************************************************************************
  * The advanced API of QDBM
- *                                                      Copyright (C) 2000-2004 Mikio Hirabayashi
+ *                                                      Copyright (C) 2000-2005 Mikio Hirabayashi
  * This file is part of QDBM, Quick Database Manager.
  * QDBM is free software; you can redistribute it and/or modify it under the terms of the GNU
  * Lesser General Public License as published by the Free Software Foundation; either version
@@ -356,7 +356,7 @@ char *vlname(VILLA *villa);
 /* Get the size of a database file.
    `villa' specifies a database handle.
    If successful, the return value is the size of the database file, else, it is -1.
-   Because of the I/O buffer, the return value may be less than the real size. */
+   Because of the I/O buffer, the return value may be less than the hard size. */
 int vlfsiz(VILLA *villa);
 
 
@@ -397,6 +397,12 @@ int vlfatalerror(VILLA *villa);
 int vlinode(VILLA *villa);
 
 
+/* Get the last modified time of a database.
+   `villa' specifies a database handle.
+   The return value is the last modified time of the database. */
+int vlmtime(VILLA *villa);
+
+
 /* Begin the transaction.
    `villa' specifies a database handle connected as a writer.
    If successful, the return value is true, else, it is false.
@@ -436,6 +442,21 @@ int vlremove(const char *name);
 int vlrepair(const char *name, VLCFUNC cmp);
 
 
+/* Dump all records as endian independent data.
+   `villa' specifies a database handle.
+   `name' specifies the name of an output file.
+   If successful, the return value is true, else, it is false. */
+int vlexportdb(VILLA *villa, const char *name);
+
+
+/* Load all records from endian independent data.
+   `villa' specifies a database handle connected as a writer.  The database of the handle must
+   be empty.
+   `name' specifies the name of an input file.
+   If successful, the return value is true, else, it is false. */
+int vlimportdb(VILLA *villa, const char *name);
+
+
 
 #if defined(__cplusplus)                 /* export for C++ */
 }
