@@ -1,6 +1,6 @@
 /*************************************************************************************************
  * Utility for debugging Villa and its applications
- *                                                      Copyright (C) 2000-2004 Mikio Hirabayashi
+ *                                                      Copyright (C) 2000-2005 Mikio Hirabayashi
  * This file is part of QDBM, Quick Database Manager.
  * QDBM is free software; you can redistribute it and/or modify it under the terms of the GNU
  * Lesser General Public License as published by the Free Software Foundation; either version
@@ -52,6 +52,8 @@ int runoptimize(int argc, char **argv);
 int runinform(int argc, char **argv);
 int runremove(int argc, char **argv);
 int runrepair(int argc, char **argv);
+int runexportdb(int argc, char **argv);
+int runimportdb(int argc, char **argv);
 void pdperror(const char *name);
 void printobj(const char *obj, int size);
 void printobjhex(const char *obj, int size);
@@ -66,6 +68,8 @@ int dooptimize(const char *name);
 int doinform(const char *name);
 int doremove(const char *name);
 int dorepair(const char *name, VLCFUNC cmp);
+int doexportdb(const char *name, const char *file, VLCFUNC cmp);
+int doimportdb(const char *name, const char *file, VLCFUNC cmp);
 
 
 /* main routine */
@@ -95,9 +99,13 @@ int main(int argc, char **argv){
     rv = runremove(argc, argv);
   } else if(!strcmp(argv[1], "repair")){
     rv = runrepair(argc, argv);
+  } else if(!strcmp(argv[1], "exportdb")){
+    rv = runexportdb(argc, argv);
+  } else if(!strcmp(argv[1], "importdb")){
+    rv = runimportdb(argc, argv);
   } else if(!strcmp(argv[1], "version") || !strcmp(argv[1], "--version")){
     printf("Powered by QDBM version %s on %s\n", dpversion, dpsysname);
-    printf("Copyright (c) 2000-2004 Mikio Hirabayashi\n");
+    printf("Copyright (c) 2000-2005 Mikio Hirabayashi\n");
     rv = 0;
   } else {
     usage();
@@ -121,6 +129,8 @@ void usage(void){
   fprintf(stderr, "  %s inform name\n", progname);
   fprintf(stderr, "  %s remove name\n", progname);
   fprintf(stderr, "  %s repair [-ki] name\n", progname);
+  fprintf(stderr, "  %s exportdb [-ki] name file\n", progname);
+  fprintf(stderr, "  %s importdb [-ki] name file\n", progname);
   fprintf(stderr, "  %s version\n", progname);
   fprintf(stderr, "\n");
   exit(1);
@@ -524,6 +534,62 @@ int runrepair(int argc, char **argv){
 }
 
 
+/* parse arguments of exportdb command */
+int runexportdb(int argc, char **argv){
+  char *name, *file;
+  int i, ki, rv;
+  name = NULL;
+  file = NULL;
+  ki = FALSE;
+  for(i = 2; i < argc; i++){
+    if(!name && argv[i][0] == '-'){
+      if(!strcmp(argv[i], "-ki")){
+        ki = TRUE;
+      } else {
+        usage();
+      }
+    } else if(!name){
+      name = argv[i];
+    } else if(!file){
+      file = argv[i];
+    } else {
+      usage();
+    }
+  }
+  if(!name || !file) usage();
+  rv = doexportdb(name, file, ki ? VL_CMPINT : VL_CMPLEX);
+  return rv;
+}
+
+
+/* parse arguments of importdb command */
+int runimportdb(int argc, char **argv){
+  char *name, *file;
+  int i, ki, rv;
+  name = NULL;
+  file = NULL;
+  ki = FALSE;
+  for(i = 2; i < argc; i++){
+    if(!name && argv[i][0] == '-'){
+      if(!strcmp(argv[i], "-ki")){
+        ki = TRUE;
+      } else {
+        usage();
+      }
+    } else if(!name){
+      name = argv[i];
+    } else if(!file){
+      file = argv[i];
+    } else {
+      usage();
+    }
+  }
+  if(!name || !file) usage();
+  rv = doimportdb(name, file, ki ? VL_CMPINT : VL_CMPLEX);
+  return rv;
+}
+
+
 /* print an error message */
 void pdperror(const char *name){
   fprintf(stderr, "%s: %s: %s\n", progname, name, dperrmsg(dpecode));
@@ -803,6 +869,7 @@ int doinform(const char *name){
   printf("non-leaf nodes: %d\n", vlnnum(villa));
   printf("records: %d\n", vlrnum(villa));
   printf("inode number: %d\n", vlinode(villa));
+  printf("modified time: %d\n", vlmtime(villa));
   if(!vlclose(villa)){
     pdperror(name);
     return 1;
@@ -831,5 +898,45 @@ int dorepair(const char *name, VLCFUNC cmp){
 }
 
 
+/* perform exportdb command */
+int doexportdb(const char *name, const char *file, VLCFUNC cmp){
+  VILLA *villa;
+  if(!(villa = vlopen(name, VL_OREADER, cmp))){
+    pdperror(name);
+    return 1;
+  }
+  if(!vlexportdb(villa, file)){
+    pdperror(name);
+    vlclose(villa);
+    return 1;
+  }
+  if(!vlclose(villa)){
+    pdperror(name);
+    return 1;
+  }
+  return 0;
+}
+
+
+/* perform importdb command */
+int doimportdb(const char *name, const char *file, VLCFUNC cmp){
+  VILLA *villa;
+  if(!(villa = vlopen(name, VL_OWRITER | VL_OCREAT | VL_OTRUNC, cmp))){
+    pdperror(name);
+    return 1;
+  }
+  if(!vlimportdb(villa, file)){
+    pdperror(name);
+    vlclose(villa);
+    return 1;
+  }
+  if(!vlclose(villa)){
+    pdperror(name);
+    return 1;
+  }
+  return 0;
+}
+
+
 
 /* END OF FILE */
