@@ -1,6 +1,6 @@
 /*************************************************************************************************
  * Test cases of Villa
- *                                                      Copyright (C) 2000-2004 Mikio Hirabayashi
+ *                                                      Copyright (C) 2000-2005 Mikio Hirabayashi
  * This file is part of QDBM, Quick Database Manager.
  * QDBM is free software; you can redistribute it and/or modify it under the terms of the GNU
  * Lesser General Public License as published by the Free Software Foundation; either version
@@ -93,10 +93,10 @@ void usage(void){
   fprintf(stderr, "%s: test cases for Villa\n", progname);
   fprintf(stderr, "\n");
   fprintf(stderr, "usage:\n");
-  fprintf(stderr, "  %s write [-int] [-zc] [-tune lrecmax nidmax lcnum ncnum] name rnum\n",
+  fprintf(stderr, "  %s write [-int] [-zc] [-tune lrecmax nidxmax lcnum ncnum] name rnum\n",
           progname);
   fprintf(stderr, "  %s read [-int] name\n", progname);
-  fprintf(stderr, "  %s rdup [-int] [-zc] [-tune lrecmax nidmax lcnum ncnum] name rnum pnum\n",
+  fprintf(stderr, "  %s rdup [-int] [-zc] [-tune lrecmax nidxmax lcnum ncnum] name rnum pnum\n",
           progname);
   fprintf(stderr, "  %s combo [-zc] name\n", progname);
   fprintf(stderr, "  %s wicked [-zc] name rnum\n", progname);
@@ -1062,6 +1062,10 @@ int dowicked(const char *name, int rnum, int zc){
       }
       break;
     case 10:
+      if(myrand() % 32 != 0){
+        putchar('N');
+        break;
+      }
       putchar('T');
       if(tran){
         if(myrand() % 5 == 0){
